==> wdijkerman-zabbix-2.1.0.tar.gz: wdijkerman-zabbix-2.1.0/spec/classes/proxy_spec.rb <==
require 'spec_helper'

describe 'zabbix::proxy' do
  let (:node) { 'rspec.puppet.com' }

  let (:params) do
    {
      :zabbix_server_host => '192.168.1.1',
      :zabbix_version => '2.4'
    }
  end

  context 'On RedHat 6.5' do
    let (:facts) do
      {
        :osfamily                  => 'RedHat',
        :operatingsystem           => 'RedHat',
        :operatingsystemrelease    => '6.5',
        :operatingsystemmajrelease => '6',
        :architecture              => 'x86_64',
        :lsbdistid                 => 'RedHat',
        :concat_basedir            => '/tmp',
      }
    end
  
    let (:pre_condition) do
      "class {'postgresql::server':}"
    end

    it { should contain_file('/etc/zabbix/zabbix_proxy.conf.d').with_ensure('directory') }
    it { should contain_file('/etc/zabbix/zabbix_proxy.conf.d').with_require('File[/etc/zabbix/zabbix_proxy.conf]') }
  
    describe "when manage_repo is true" do
      let (:params) do
        {
          :manage_repo => true,
        }
      end

      it { should contain_class('zabbix::repo').with_zabbix_version('2.4') }
      it { should contain_package('zabbix-proxy-pgsql').with_require('Class[Zabbix::Repo]') }
    end

    describe "when database_type is postgresql" do
      let (:params) do
        {
          :database_type => 'postgresql',
        }
      end

      it { should contain_package('zabbix-proxy-pgsql').with_ensure('present') }
      it { should contain_package('zabbix-proxy-pgsql').with_ensure('present') }
      it { should contain_package('zabbix-proxy-pgsql').with_name('zabbix-proxy-pgsql') }
      it { should contain_service('zabbix-proxy').with_require(['Package[zabbix-proxy-pgsql]','File[/etc/zabbix/zabbix_proxy.conf.d]','File[/etc/zabbix/zabbix_proxy.conf]']) }
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_require('Package[zabbix-proxy-pgsql]') }
    end

    describe "when database_type is mysql" do
      let (:params) do
        {
          :database_type => 'mysql',
        }
      end

      it { should contain_package('zabbix-proxy-mysql').with_ensure('present') }
      it { should contain_package('zabbix-proxy-mysql').with_ensure('present') }
      it { should contain_package('zabbix-proxy-mysql').with_name('zabbix-proxy-mysql') }
      it { should contain_service('zabbix-proxy').with_require(['Package[zabbix-proxy-mysql]','File[/etc/zabbix/zabbix_proxy.conf.d]','File[/etc/zabbix/zabbix_proxy.conf]']) }
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_require('Package[zabbix-proxy-mysql]') }
    end

    describe "when manage_resources is true" do
      let (:params) do
        {
          :manage_resources => true,
        }
      end

      it { should contain_class('zabbix::resources::proxy') }
    end

    context 'with zabbix::database::postgresql class' do
      let (:params) do
        {
          :database_type => 'postgresql',
          :manage_database => true,
        }
      end

      it { should contain_class('zabbix::database::postgresql').with_zabbix_type('proxy')}
      it { should contain_class('zabbix::database::postgresql').with_zabbix_version('2.4')}
      it { should contain_class('zabbix::database::postgresql').with_database_name('zabbix_proxy')}
      it { should contain_class('zabbix::database::postgresql').with_database_user('zabbix-proxy')}
      it { should contain_class('zabbix::database::postgresql').with_database_password('zabbix-proxy')}
      it { should contain_class('zabbix::database::postgresql').with_database_host('localhost')}
    end

    context 'with zabbix::database::mysql class' do
      let(:params) do
        {
          :database_type => 'mysql',
          :manage_database => true,
        }
      end

      let(:pre_condition) do
        "include 'mysql::server'"
      end

      it { should contain_class('zabbix::database::mysql').with_zabbix_type('proxy')}
      it { should contain_class('zabbix::database::mysql').with_zabbix_version('2.4')}
      it { should contain_class('zabbix::database::mysql').with_database_name('zabbix_proxy')}
      it { should contain_class('zabbix::database::mysql').with_database_user('zabbix-proxy')}
      it { should contain_class('zabbix::database::mysql').with_database_password('zabbix-proxy')}
      it { should contain_class('zabbix::database::mysql').with_database_host('localhost')}
    end

    context 'when manage_database is true' do
      let(:params) do
        {
          :manage_database => true,
        }
      end

      it { should contain_class('zabbix::database').with_zabbix_type('proxy')}
      it { should contain_class('zabbix::database').with_database_type('postgresql')}
      it { should contain_class('zabbix::database').with_database_name('zabbix_proxy')}
      it { should contain_class('zabbix::database').with_database_user('zabbix-proxy')}
      it { should contain_class('zabbix::database').with_database_password('zabbix-proxy')}
      it { should contain_class('zabbix::database').with_database_host('localhost')}
      it { should contain_class('zabbix::database').with_zabbix_proxy('localhost')}
      it { should contain_class('zabbix::database').with_zabbix_proxy_ip('127.0.0.1')}
    end

    context "when declaring manage_firewall is true" do
      let(:params) do
        {
          :manage_firewall => true,
        }
      end

      it { should contain_firewall('151 zabbix-proxy') }
    end

    context "when declaring manage_firewall is false" do
      let(:params) do
        {
          :manage_firewall => false,
        }
      end

      it { should_not contain_firewall('151 zabbix-proxy') }
    end


    # Make sure we have set some vars in zabbix_proxy.conf file. This is configuration file is the same on all
    # operating systems. So we aren't testing this for all opeating systems, just this one.
    context 'with zabbix_proxy.conf settings' do
      let(:params) do
        {
          :allowroot               => '0',
          :cachesize               => '8M',
          :configfrequency         => '3600',
          :database_host           => 'localhost',
          :database_name           => 'zabbix-proxy',
          :database_password       => 'zabbix-proxy',
          :database_schema         => 'zabbix-proxy',
          :database_user           => 'zabbix-proxy',
          :datasenderfrequency     => '1',
          :debuglevel              => '4',
          :externalscripts         => '/usr/lib/zabbix/externalscripts',
          :fping6location          => '/usr/sbin/fping6',
          :fpinglocation           => '60',
          :heartbeatfrequency      => '60',
          :historycachesize        => '16M',
          :historytextcachesize    => '8M',
          :hostname                => 'rspec.puppet.com',
          :housekeepingfrequency   => '1',
          :include_dir             => '/etc/zabbix/zabbix_proxy.conf.d',
          :javagateway             => '192.168.1.2',
          :javagatewayport         => '10051',
          :startjavapollers        => '5',
          :listenip                => '192.168.1.1',
          :listenport              => '10051',
          :loadmodulepath          => '${libdir}/modules',
          :loadmodule              => 'pizza',
          :localbuffer             => '0',
          :logfilesize             => '15',
          :logfile                 => '/var/log/zabbix/proxy_server.log',
          :loglowqueries           => '0',
          :mode                    => '0',
          :offlinebuffer           => '1',
          :pidfile                 => '/var/run/zabbix/proxy_server.pid',
          :snmptrapper             => '0',
          :snmptrapperfile         => '/tmp/zabbix_traps.tmp',
          :sshkeylocation          => '/home/zabbix/.ssh/',
          :startdbsyncers          => '4',
          :startdiscoverers        => '15',
          :starthttppollers        => '15',
          :startipmipollers        => '15',
          :startpingers            => '15',
          :startpollers            => '15',
          :startpollersunreachable => '15',
          :starttrappers           => '15',
          :startvmwarecollectors   => '0',
          :timeout                 => '20',
          :tmpdir                  => '/tmp',
          :trappertimeout          => '16',
          :unavaliabledelay        => '60',
          :unreachabedelay         => '15',
          :unreachableperiod       => '45',
          :vmwarecachesize         => '8M',
          :vmwarefrequency         => '60',
          :zabbix_server_host      => '192.168.1.1',
          :zabbix_server_port      => '10051',
          :zabbix_version          => '2.2',
        }
      end

      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ProxyMode=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Server=192.168.1.1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ServerPort=10051$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Hostname=rspec.puppet.com$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ListenPort=10051$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LogFile=/var/log/zabbix/proxy_server.log$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LogFileSize=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DebugLevel=4$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^PidFile=/var/run/zabbix/proxy_server.pid$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBHost=localhost$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBName=zabbix-proxy$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBSchema=zabbix-proxy$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBUser=zabbix-proxy$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBPassword=zabbix-proxy$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ProxyLocalBuffer=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ProxyOfflineBuffer=1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^HeartbeatFrequency=60$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ConfigFrequency=3600$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DataSenderFrequency=1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartPollers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartIPMIPollers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartPollersUnreachable=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartTrappers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartPingers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartDiscoverers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartHTTPPollers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^JavaGateway=192.168.1.2$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^JavaGatewayPort=10051$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartJavaPollers=5$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartVMwareCollectors=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^VMwareFrequency=60$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^VMwareCacheSize=8M$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^SNMPTrapperFile=/tmp/zabbix_traps.tmp$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartSNMPTrapper=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ListenIP=192.168.1.1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^HousekeepingFrequency=1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^CacheSize=8M$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartDBSyncers=4$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^HistoryCacheSize=16M$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^HistoryTextCacheSize=8M$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Timeout=20$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TrapperTimeout=16$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^UnreachablePeriod=45$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^UnavailableDelay=60$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^UnreachableDelay=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ExternalScripts=/usr/lib/zabbix/externalscripts$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^FpingLocation=60$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Fping6Location=/usr/sbin/fping6$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^SSHKeyLocation=/home/zabbix/.ssh/$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LogSlowQueries=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TmpDir=/tmp$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^AllowRoot=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Include=/etc/zabbix/zabbix_proxy.conf.d$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LoadModulePath=\$\{libdir\}/modules$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LoadModule=pizza$}}
    end  
  end # END context 'zabbix_proxy.conf configuration'
end

==> wdijkerman-zabbix-2.2.0.tar.gz: wdijkerman-zabbix-2.2.0/spec/classes/proxy_spec.rb <==
require 'spec_helper'

describe 'zabbix::proxy' do
  let (:node) { 'rspec.puppet.com' }

  let (:params) do
    {
      :zabbix_server_host => '192.168.1.1',
      :zabbix_version => '2.4'
    }
  end

  context 'On RedHat 7.1' do
    let (:facts) do
      {
        :osfamily                  => 'RedHat',
        :operatingsystem           => 'RedHat',
        :operatingsystemrelease    => '7.1',
        :operatingsystemmajrelease => '7',
        :architecture              => 'x86_64',
        :lsbdistid                 => 'RedHat',
        :concat_basedir            => '/tmp',
      }
    end
  
    let (:pre_condition) do
      "class {'postgresql::server':}"
    end

    it { should contain_file('/etc/zabbix/zabbix_proxy.conf.d').with_ensure('directory') }
    it { should contain_file('/etc/zabbix/zabbix_proxy.conf.d').with_require('File[/etc/zabbix/zabbix_proxy.conf]') }
  
    describe "when manage_repo is true" do
      let (:params) do
        {
          :manage_repo => true,
        }
      end

      it { should contain_class('zabbix::repo').with_zabbix_version('3.0') }
      it { should contain_package('zabbix-proxy-pgsql').with_require('Class[Zabbix::Repo]') }
    end

    describe "when database_type is postgresql" do
      let (:params) do
        {
          :database_type => 'postgresql',
        }
      end

      it { should contain_package('zabbix-proxy-pgsql').with_ensure('present') }
      it { should contain_package('zabbix-proxy-pgsql').with_ensure('present') }
      it { should contain_package('zabbix-proxy-pgsql').with_name('zabbix-proxy-pgsql') }
      it { should contain_service('zabbix-proxy').with_require(['Package[zabbix-proxy-pgsql]','File[/etc/zabbix/zabbix_proxy.conf.d]','File[/etc/zabbix/zabbix_proxy.conf]']) }
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_require('Package[zabbix-proxy-pgsql]') }
    end

    describe "when database_type is mysql" do
      let (:params) do
        {
          :database_type => 'mysql',
        }
      end

      it { should contain_package('zabbix-proxy-mysql').with_ensure('present') }
      it { should contain_package('zabbix-proxy-mysql').with_ensure('present') }
      it { should contain_package('zabbix-proxy-mysql').with_name('zabbix-proxy-mysql') }
      it { should contain_service('zabbix-proxy').with_require(['Package[zabbix-proxy-mysql]','File[/etc/zabbix/zabbix_proxy.conf.d]','File[/etc/zabbix/zabbix_proxy.conf]']) }
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_require('Package[zabbix-proxy-mysql]') }
    end

    describe "when manage_resources is true" do
      let (:params) do
        {
          :manage_resources => true,
        }
      end

      it { should contain_class('zabbix::resources::proxy') }
    end

    context 'with zabbix::database::postgresql class' do
      let (:params) do
        {
          :database_type => 'postgresql',
          :manage_database => true,
        }
      end

      it { should contain_class('zabbix::database::postgresql').with_zabbix_type('proxy')}
      it { should contain_class('zabbix::database::postgresql').with_zabbix_version('3.0')}
      it { should contain_class('zabbix::database::postgresql').with_database_name('zabbix_proxy')}
      it { should contain_class('zabbix::database::postgresql').with_database_user('zabbix-proxy')}
      it { should contain_class('zabbix::database::postgresql').with_database_password('zabbix-proxy')}
      it { should contain_class('zabbix::database::postgresql').with_database_host('localhost')}
    end

    context 'with zabbix::database::mysql class' do
      let(:params) do
        {
          :database_type => 'mysql',
          :manage_database => true,
        }
      end

      let(:pre_condition) do
        "include 'mysql::server'"
      end

      it { should contain_class('zabbix::database::mysql').with_zabbix_type('proxy')}
      it { should contain_class('zabbix::database::mysql').with_zabbix_version('3.0')}
      it { should contain_class('zabbix::database::mysql').with_database_name('zabbix_proxy')}
      it { should contain_class('zabbix::database::mysql').with_database_user('zabbix-proxy')}
      it { should contain_class('zabbix::database::mysql').with_database_password('zabbix-proxy')}
      it { should contain_class('zabbix::database::mysql').with_database_host('localhost')}
    end

    context 'when manage_database is true' do
      let(:params) do
        {
          :manage_database => true,
        }
      end

      it { should contain_class('zabbix::database').with_zabbix_type('proxy')}
      it { should contain_class('zabbix::database').with_database_type('postgresql')}
      it { should contain_class('zabbix::database').with_database_name('zabbix_proxy')}
      it { should contain_class('zabbix::database').with_database_user('zabbix-proxy')}
      it { should contain_class('zabbix::database').with_database_password('zabbix-proxy')}
      it { should contain_class('zabbix::database').with_database_host('localhost')}
      it { should contain_class('zabbix::database').with_zabbix_proxy('localhost')}
      it { should contain_class('zabbix::database').with_zabbix_proxy_ip('127.0.0.1')}
    end

    context "when declaring manage_firewall is true" do
      let(:params) do
        {
          :manage_firewall => true,
        }
      end

      it { should contain_firewall('151 zabbix-proxy') }
    end

    context "when declaring manage_firewall is false" do
      let(:params) do
        {
          :manage_firewall => false,
        }
      end

      it { should_not contain_firewall('151 zabbix-proxy') }
    end


    # Make sure we have set some vars in zabbix_proxy.conf file. This is configuration file is the same on all
    # operating systems. So we aren't testing this for all opeating systems, just this one.
    context 'with zabbix_proxy.conf settings' do
      let(:params) do
        {
          :allowroot               => '0',
          :cachesize               => '8M',
          :configfrequency         => '3600',
          :database_host           => 'localhost',
          :database_name           => 'zabbix-proxy',
          :database_password       => 'zabbix-proxy',
          :database_schema         => 'zabbix-proxy',
          :database_user           => 'zabbix-proxy',
          :datasenderfrequency     => '1',
          :debuglevel              => '4',
          :externalscripts         => '/usr/lib/zabbix/externalscripts',
          :fping6location          => '/usr/sbin/fping6',
          :fpinglocation           => '60',
          :heartbeatfrequency      => '60',
          :historycachesize        => '16M',
          :historytextcachesize    => '8M',
          :hostname                => 'rspec.puppet.com',
          :housekeepingfrequency   => '1',
          :include_dir             => '/etc/zabbix/zabbix_proxy.conf.d',
          :javagateway             => '192.168.1.2',
          :javagatewayport         => '10051',
          :startjavapollers        => '5',
          :listenip                => '192.168.1.1',
          :listenport              => '10051',
          :loadmodulepath          => '${libdir}/modules',
          :loadmodule              => 'pizza',
          :localbuffer             => '0',
          :logfilesize             => '15',
          :logfile                 => '/var/log/zabbix/proxy_server.log',
          :logslowqueries          => '0',
          :mode                    => '0',
          :offlinebuffer           => '1',
          :pidfile                 => '/var/run/zabbix/proxy_server.pid',
          :snmptrapper             => '0',
          :snmptrapperfile         => '/tmp/zabbix_traps.tmp',
          :sshkeylocation          => '/home/zabbix/.ssh/',
          :startdbsyncers          => '4',
          :startdiscoverers        => '15',
          :starthttppollers        => '15',
          :startipmipollers        => '15',
          :startpingers            => '15',
          :startpollers            => '15',
          :startpollersunreachable => '15',
          :starttrappers           => '15',
          :startvmwarecollectors   => '0',
          :timeout                 => '20',
          :tmpdir                  => '/tmp',
          :trappertimeout          => '16',
          :unavaliabledelay        => '60',
          :unreachabedelay         => '15',
          :unreachableperiod       => '45',
          :vmwarecachesize         => '8M',
          :vmwarefrequency         => '60',
          :zabbix_server_host      => '192.168.1.1',
          :zabbix_server_port      => '10051',
          :zabbix_version          => '2.2',
        }
      end

      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ProxyMode=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Server=192.168.1.1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ServerPort=10051$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Hostname=rspec.puppet.com$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ListenPort=10051$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LogFile=/var/log/zabbix/proxy_server.log$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LogFileSize=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DebugLevel=4$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^PidFile=/var/run/zabbix/proxy_server.pid$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBHost=localhost$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBName=zabbix-proxy$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBSchema=zabbix-proxy$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBUser=zabbix-proxy$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DBPassword=zabbix-proxy$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ProxyLocalBuffer=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ProxyOfflineBuffer=1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^HeartbeatFrequency=60$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ConfigFrequency=3600$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^DataSenderFrequency=1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartPollers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartIPMIPollers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartPollersUnreachable=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartTrappers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartPingers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartDiscoverers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartHTTPPollers=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^JavaGateway=192.168.1.2$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^JavaGatewayPort=10051$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartJavaPollers=5$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartVMwareCollectors=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^VMwareFrequency=60$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^VMwareCacheSize=8M$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^SNMPTrapperFile=/tmp/zabbix_traps.tmp$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartSNMPTrapper=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ListenIP=192.168.1.1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^HousekeepingFrequency=1$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^CacheSize=8M$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^StartDBSyncers=4$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^HistoryCacheSize=16M$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^HistoryTextCacheSize=8M$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Timeout=20$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TrapperTimeout=16$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^UnreachablePeriod=45$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^UnavailableDelay=60$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^UnreachableDelay=15$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^ExternalScripts=/usr/lib/zabbix/externalscripts$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^FpingLocation=60$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Fping6Location=/usr/sbin/fping6$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^SSHKeyLocation=/home/zabbix/.ssh/$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LogSlowQueries=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TmpDir=/tmp$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^AllowRoot=0$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^Include=/etc/zabbix/zabbix_proxy.conf.d$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LoadModulePath=\$\{libdir\}/modules$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^LoadModule=pizza$}}
    end

    context "with zabbix_proxy.conf and version 3.0" do
      let (:params) do
        {
          :tlsaccept => 'cert',
          :tlscafile => '/etc/zabbix/keys/zabbix-server.ca',
          :tlscrlfile => '/etc/zabbix/keys/zabbix-server.crl',
          :tlscertfile => '/etc/zabbix/keys/zabbix-server.crt',
          :tlskeyfile => '/etc/zabbix/keys/zabbix-server.key',
          :tlsservercertissuer => 'Zabbix.Com',
          :tlsservercertsubject => 'MyZabbix',
          :tlspskidentity => '/etc/zabbix/keys/identity.file',
          :tlspskfile => '/etc/zabbix/keys/file.key',
          :zabbix_version => '3.0',
        }
      end

      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TLSAccept=cert$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TLSCAFile=/etc/zabbix/keys/zabbix-server.ca$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TLSCRLFile=/etc/zabbix/keys/zabbix-server.crl$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TLSCertFile=/etc/zabbix/keys/zabbix-server.crt$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TLSKeyFile=/etc/zabbix/keys/zabbix-server.key$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TLSServerCertIssuer=Zabbix.Com$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TLSServerCertSubject=MyZabbix$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TLSPSKIdentity=/etc/zabbix/keys/identity.file$}}
      it { should contain_file('/etc/zabbix/zabbix_proxy.conf').with_content %r{^TLSPSKFile=/etc/zabbix/keys/file.key$}}
    end 
    
    
  end # END context 'zabbix_proxy.conf configuration'
end
